@@ -1,9 +1,10 @@
 from enum import Enum
-from pm4py.util import exec_utils
+from pm4py.util import exec_utils, xes_constants, constants
 from pm4py.algo.discovery.footprints.outputs import Outputs
 
 
 class Parameters(Enum):
+    CASE_ID_KEY = constants.PARAMETER_CONSTANT_CASEID_KEY
     STRICT = "strict"
 
 
@@ -75,3 +76,40 @@ def apply(log_footprints, model_footprints, parameters=None):
             ret.append(apply_single(case_footprints, model_footprints, parameters=parameters))
         return ret
     return apply_single(log_footprints, model_footprints, parameters=parameters)
+
+
+def get_diagnostics_dataframe(log, conf_result, parameters=None):
+    """
+    Gets the diagnostics dataframe from the log
+    and the results of footprints conformance checking
+    (trace-by-trace)
+
+    Parameters
+    --------------
+    log
+        Event log
+    conf_result
+        Conformance checking results (trace-by-trace)
+
+    Returns
+    --------------
+    diagn_dataframe
+        Diagnostics dataframe
+    """
+    if parameters is None:
+        parameters = {}
+
+    case_id_key = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, xes_constants.DEFAULT_TRACEID_KEY)
+
+    import pandas as pd
+
+    diagn_stream = []
+
+    for index in range(len(log)):
+        case_id = log[index].attributes[case_id_key]
+        num_violations = len(conf_result[index])
+        is_fit = num_violations == 0
+
+        diagn_stream.append({"case_id": case_id, "num_violations": num_violations, "is_fit": is_fit})
+
+    return pd.DataFrame(diagn_stream)
