@@ -1,4 +1,4 @@
-from pm4py.algo.discovery.correlation_mining.versions import classic_split, classic, trace_based
+from pm4py.algo.discovery.correlation_mining.variants import classic_split, classic, trace_based
 from pm4py.util import exec_utils
 from enum import Enum
 
