@@ -1,5 +1,5 @@
 import pm4py.algo.conformance.alignments.algorithm as ali
-from pm4py.algo.conformance.alignments.versions import state_equation_a_star as star
+from pm4py.algo.conformance.alignments.variants import state_equation_a_star as star
 import sys
 import pandas as pd
 from pm4py.statistics.variants.log import get as variants_module
