@@ -4,10 +4,20 @@ from pm4py.statistics.end_activities.pandas.get import get_end_activities
 from pm4py.util.constants import CASE_CONCEPT_NAME
 from pm4py.util import xes_constants as xes
 from pm4py.util.xes_constants import DEFAULT_NAME_KEY
-from pm4py.util import constants
 from pm4py.util.constants import PARAMETER_CONSTANT_CASEID_KEY, PARAMETER_CONSTANT_ACTIVITY_KEY, GROUPED_DATAFRAME, \
     RETURN_EA_COUNT_DICT_AUTOFILTER
 from pm4py.util.constants import PARAM_MOST_COMMON_VARIANT
+from enum import Enum
+from pm4py.util import exec_utils
+
+
+class Parameters(Enum):
+    CASE_ID_KEY = PARAMETER_CONSTANT_CASEID_KEY
+    ACTIVITY_KEY = PARAMETER_CONSTANT_ACTIVITY_KEY
+    DECREASING_FACTOR = "decreasingFactor"
+    GROUP_DATAFRAME = GROUPED_DATAFRAME
+    POSITIVE = "positive"
+    RETURN_EA_COUNT = RETURN_EA_COUNT_DICT_AUTOFILTER
 
 
 def apply(df, values, parameters=None):
@@ -22,9 +32,9 @@ def apply(df, values, parameters=None):
         Values to filter on
     parameters
         Possible parameters of the algorithm, including:
-            case_id_glue -> Case ID column in the dataframe
-            activity_key -> Column that represents the activity
-            positive -> Specifies if the filtered should be applied including traces (positive=True)
+            Parameters.CASE_ID_KEY -> Case ID column in the dataframe
+            Parameters.ACTIVITY_KEY -> Column that represents the activity
+            Parameters.POSITIVE -> Specifies if the filtered should be applied including traces (positive=True)
             or excluding traces (positive=False)
 
     Returns
@@ -34,13 +44,11 @@ def apply(df, values, parameters=None):
     """
     if parameters is None:
         parameters = {}
-    case_id_glue = parameters[
-        PARAMETER_CONSTANT_CASEID_KEY] if PARAMETER_CONSTANT_CASEID_KEY in parameters else CASE_CONCEPT_NAME
-    activity_key = parameters[
-        PARAMETER_CONSTANT_ACTIVITY_KEY] if PARAMETER_CONSTANT_ACTIVITY_KEY in parameters else DEFAULT_NAME_KEY
-    grouped_df = parameters[GROUPED_DATAFRAME] if GROUPED_DATAFRAME in parameters else None
 
-    positive = parameters["positive"] if "positive" in parameters else True
+    case_id_glue = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, CASE_CONCEPT_NAME)
+    activity_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, DEFAULT_NAME_KEY)
+    grouped_df = exec_utils.get_param_value(Parameters.GROUP_DATAFRAME, parameters, None)
+    positive = exec_utils.get_param_value(Parameters.POSITIVE, parameters, True)
 
     return filter_df_on_end_activities(df, values, case_id_glue=case_id_glue, activity_key=activity_key,
                                        positive=positive, grouped_df=grouped_df)
@@ -56,9 +64,9 @@ def apply_auto_filter(df, parameters=None):
         Pandas dataframe
     parameters
         Parameters of the algorithm, including:
-            case_id_glue -> Case ID column in the dataframe
-            activity_key -> Column that represents the activity
-            decreasingFactor -> Decreasing factor that should be passed to the algorithm
+            Parameters.CASE_ID_KEY -> Case ID column in the dataframe
+            Parameters.ACTIVITY_KEY -> Column that represents the activity
+            Parameters.DECREASING_FACTOR -> Decreasing factor that should be passed to the algorithm
 
     Returns
     -----------
@@ -68,29 +76,26 @@ def apply_auto_filter(df, parameters=None):
     if parameters is None:
         parameters = {}
 
+    case_id_glue = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, CASE_CONCEPT_NAME)
+    activity_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, DEFAULT_NAME_KEY)
+    grouped_df = exec_utils.get_param_value(Parameters.GROUP_DATAFRAME, parameters, None)
+    return_dict = exec_utils.get_param_value(Parameters.RETURN_EA_COUNT, parameters, False)
+    decreasing_factor = exec_utils.get_param_value(Parameters.DECREASING_FACTOR, parameters,
+                                                   filtering_constants.DECREASING_FACTOR)
+
     most_common_variant = parameters[PARAM_MOST_COMMON_VARIANT] if PARAM_MOST_COMMON_VARIANT in parameters else None
 
     if most_common_variant is None:
         most_common_variant = []
 
-    case_id_glue = parameters[
-        PARAMETER_CONSTANT_CASEID_KEY] if PARAMETER_CONSTANT_CASEID_KEY in parameters else CASE_CONCEPT_NAME
-    activity_key = parameters[
-        PARAMETER_CONSTANT_ACTIVITY_KEY] if PARAMETER_CONSTANT_ACTIVITY_KEY in parameters else DEFAULT_NAME_KEY
-    grouped_df = parameters[GROUPED_DATAFRAME] if GROUPED_DATAFRAME in parameters else None
-    return_dict = parameters[
-        RETURN_EA_COUNT_DICT_AUTOFILTER] if RETURN_EA_COUNT_DICT_AUTOFILTER in parameters else False
-
-    decreasing_factor = parameters[
-        "decreasingFactor"] if "decreasingFactor" in parameters else filtering_constants.DECREASING_FACTOR
-
     if len(df) > 0:
         end_activities = get_end_activities(df, parameters=parameters)
         ealist = end_activities_common.get_sorted_end_activities_list(end_activities)
         eathreshold = end_activities_common.get_end_activities_threshold(ealist, decreasing_factor)
 
         return filter_df_on_end_activities_nocc(df, eathreshold, ea_count0=end_activities, case_id_glue=case_id_glue,
-                                                activity_key=activity_key, grouped_df=grouped_df, return_dict=return_dict,
+                                                activity_key=activity_key, grouped_df=grouped_df,
+                                                return_dict=return_dict,
                                                 most_common_variant=most_common_variant)
 
     if return_dict:
@@ -166,9 +171,9 @@ def filter_df_on_end_activities_nocc(df, nocc, ea_count0=None, case_id_glue=CASE
         first_eve_df = grouped_df.last()
         if ea_count0 is None:
             parameters = {
-                constants.PARAMETER_CONSTANT_CASEID_KEY: case_id_glue,
-                constants.PARAMETER_CONSTANT_ACTIVITY_KEY: activity_key,
-                constants.GROUPED_DATAFRAME: grouped_df
+                Parameters.CASE_ID_KEY: case_id_glue,
+                Parameters.ACTIVITY_KEY: activity_key,
+                Parameters.GROUP_DATAFRAME: grouped_df
             }
             ea_count0 = get_end_activities(df, parameters=parameters)
         ea_count = [k for k, v in ea_count0.items() if
