@@ -13,14 +13,14 @@ if pkgutil.find_loader("ciso8601"):
     #
     # ciso8601 will be installed from requirements only if the Python
     # version is <= than 3.6
-    from pm4py.util.dt_parsing.versions import cs8601
+    from pm4py.util.dt_parsing.variants import cs8601
 
     VERSIONS[CISO8601] = cs8601
     DEFAULT_VARIANT = CISO8601
 
 # this variant is available only for Python 3.7
 if sys.version_info >= (3, 7):
-    from pm4py.util.dt_parsing.versions import strpfromiso
+    from pm4py.util.dt_parsing.variants import strpfromiso
 
     VERSIONS[STRPFROMISO] = strpfromiso
     # let's move the default option to strpfromiso in Python 3.7
