@@ -1,4 +1,4 @@
-from pm4py.visualization.align_table.versions import classic
+from pm4py.visualization.align_table.variants import classic
 from pm4py.visualization.common import gview
 from pm4py.visualization.common import save as gsave
 from enum import Enum
